summaryrefslogtreecommitdiffstats
path: root/kmplot/kmplot/FktDlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmplot/kmplot/FktDlg.h')
-rw-r--r--kmplot/kmplot/FktDlg.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kmplot/kmplot/FktDlg.h b/kmplot/kmplot/FktDlg.h
index 8275b03f..c0b914e2 100644
--- a/kmplot/kmplot/FktDlg.h
+++ b/kmplot/kmplot/FktDlg.h
@@ -45,14 +45,15 @@ class XParser;
class FktDlg : public FktDlgData
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* The constructor gets the current parser instance
* @param parent Parent widget.
* @param view points to the current view instance.
*/
- FktDlg( TQWidget* parent, View* view );
+ FktDlg( TQWidget* tqparent, View* view );
/// Empty destructor.
virtual ~FktDlg();
/// Fill the widgets with plots contained in the parser instance.
@@ -45,14 +45,15 @@ class XParser;
/**
* The constructor gets the current parser instance
- * @param parent Parent widget.
+ * @param tqparent Parent widget.
* @param view points to the current view instance.
*/